@@ -125,10 +125,12 @@ void test_detector_detect_polyglot() {
   ASSERT_DETECT(LANG_CPP, "uses_cpp_stdlib_headers.h");
   ASSERT_DETECT(LANG_CPP, "uses_cpp_keywords.h");
   ASSERT_DETECT(LANG_RUBY, "foo.rb");
+  ASSERT_DETECT(LANG_CRYSTAL, "foo.cr");
   ASSERT_DETECT(LANG_MAKE, "foo.mk");
   ASSERT_DETECT(LANG_MATHEMATICA, "foo.mt");
   ASSERT_DETECT(LANG_MATHEMATICA, "foo.wl");
   ASSERT_DETECT(LANG_MATHEMATICA, "foo.wlt");
+  ASSERT_DETECT(LANG_MODELICA, "foo.mo");
   ASSERT_DETECT(LANG_OBJECTIVE_C, "foo_objective_c.h");
   ASSERT_DETECT(LANG_PHP, "upper_case_php");
   ASSERT_DETECT(LANG_SMALLTALK, "example.st");
@@ -163,13 +165,18 @@ void test_detector_detect_polyglot() {
   ASSERT_DETECT(LANG_FSHARP, "fs1.fs");
   ASSERT_DETECT(LANG_GRACE, "grace1.grace");
   ASSERT_DETECT(LANG_GRACE, "grace2.grc");
+  ASSERT_DETECT(LANG_FORTH, "forth.fs");
   ASSERT_DETECT(LANG_AUTOCONF, "m4.m4");
   ASSERT_DETECT(LANG_NSIS, "foo.nsi");
   ASSERT_DETECT(LANG_NSIS, "foo.nsh");
   ASSERT_DETECT(LANG_COFFEESCRIPT, "foo.coffee");
   ASSERT_DETECT(LANG_QML, "foo.qml");
   ASSERT_DETECT(LANG_COQ, "coq.v");
+  ASSERT_DETECT(LANG_UNREALSCRIPT, "foo.uc");
   ASSERT_DETECT(LANG_AMPL, "foo.run");
+  ASSERT_DETECT(LANG_LIVECODE, "foo.lc");
+  ASSERT_DETECT(LANG_LIVECODE, "script.utf8");
+  ASSERT_DETECT(LANG_POSTSCRIPT, "foo.ps");
   ASSERT_NODETECT("empty.inc");
 }
 
@@ -243,7 +250,7 @@ void test_detector_ampl(){
 }
 
 void test_non_existent_file(){
-  ASSERT_NODETECT("xxx_non_exists_xxxi.pp");  
+  ASSERT_NODETECT("xxx_non_exists_xxxi.pp");
 }
 
 void all_detector_tests() {
