@@ -93,6 +93,7 @@ void test_parser_verify_entity(SourceFile *sf, const char *entity,
 #include "parsers/test_clearsilver.h"
 #include "parsers/test_clojure.h"
 #include "parsers/test_coq.h"
+#include "parsers/test_crystal.h"
 #include "parsers/test_cs_aspx.h"
 #include "parsers/test_csharp.h"
 #include "parsers/test_css.h"
@@ -121,6 +122,7 @@ void test_parser_verify_entity(SourceFile *sf, const char *entity,
 #include "parsers/test_javascript.h"
 #include "parsers/test_jsp.h"
 #include "parsers/test_lisp.h"
+#include "parsers/test_livecode.h"
 #include "parsers/test_logtalk.h"
 #include "parsers/test_lua.h"
 #include "parsers/test_make.h"
@@ -137,6 +139,7 @@ void test_parser_verify_entity(SourceFile *sf, const char *entity,
 #include "parsers/test_pascal.h"
 #include "parsers/test_perl.h"
 #include "parsers/test_pike.h"
+#include "parsers/test_postscript.h"
 #include "parsers/test_puppet.h"
 #include "parsers/test_python.h"
 #include "parsers/test_qml.h"
@@ -155,6 +158,7 @@ void test_parser_verify_entity(SourceFile *sf, const char *entity,
 #include "parsers/test_stratego.h"
 #include "parsers/test_tcl.h"
 #include "parsers/test_tex.h"
+#include "parsers/test_unrealscript.h"
 #include "parsers/test_typescript.h"
 #include "parsers/test_vala.h"
 #include "parsers/test_vb_aspx.h"
@@ -280,6 +284,7 @@ void all_parser_tests() {
   all_clearsilver_tests();
   all_clojure_tests();
   all_coq_tests();
+  all_crystal_tests();
   all_cs_aspx_tests();
   all_csharp_tests();
   all_css_tests();
@@ -307,6 +312,7 @@ void all_parser_tests() {
   all_javascript_tests();
   all_jsp_tests();
   all_lisp_tests();
+  all_livecode_tests();
   all_logtalk_tests();
   all_lua_tests();
   all_make_tests();
@@ -323,6 +329,7 @@ void all_parser_tests() {
   all_pascal_tests();
   all_perl_tests();
   all_pike_tests();
+  all_postscript_tests();
   all_python_tests();
   all_r_tests();
   all_racket_tests();
@@ -339,6 +346,7 @@ void all_parser_tests() {
   all_stratego_tests();
   all_tcl_tests();
   all_tex_tests();
+  all_unrealscript_tests();
   all_vala_tests();
   all_vb_aspx_tests();
   all_vhdl_tests();
